Skip to contents

coef() retrieve all coefficients from the output of lifelihood()

coeff() retrieve coefficients of one parameter from the output of lifelihood()

Usage

# S3 method for class 'lifelihoodResults'
coef(object, ...)

coeff(object, parameter_name)

Arguments

object

output of lifelihood()

...

Ignored

parameter_name

Name of the parameters to extract the estimate from to extract all parameter estimates). All parameters#' can be found here.

Value

A nested list of coefficient estimates

A list of coefficient estimates