Skip to contents

S3 method to retrieve likelihood from the output of lifelihood()

Usage

# S3 method for class 'lifelihoodResults'
logLik(object, ...)

Arguments

object

output of lifelihood()

...

Ignored

Value

A number with the value of maximum likelihood found.