Compute time interval between clutches
Source:R/compute_event_rate.R
compute_reproduction_intervals.RdThis function computes the time interval between consecutive clutches and add censored unobserved last clutch between the last clutch and time of death unless the time of death is right censored. It also removes individuals that never reproduced.
Arguments
- lifelihoodData
Ouput of
as_lifelihoodData()- verbose
Boolean whether to print messages during the computation process (default=TRUE)