S3 method to retrieve likelihood from the output of lifelihood()
Usage
# S3 method for class 'lifelihoodResults'
logLik(object, ...)Arguments
- object
output of
lifelihood()- ...
Ignored
S3 method to retrieve likelihood from the output of lifelihood()
# S3 method for class 'lifelihoodResults'
logLik(object, ...)output of lifelihood()
Ignored