lifelihood embeds a few configuration files, and
this function is a simple tool to access one of them.
It takes the name one of the available configuration and returns the path to it.
For more info about configuration files, see
vignette("setting-up-the-configuration-file", package = "lifelihood")
Usage
use_test_config(
config_name = c("config", "config2", "config_pierrick", "example_config_se",
"example_config_mcmc", "config_gbg")
)Examples
use_test_config("config")
#> [1] "/private/var/folders/9r/xzfp9lgn603578400ms53lr00000gn/T/Rtmpl7dmnd/temp_libpath1e8b23a8b4ad/lifelihood/configs/config.yaml"
use_test_config("config2")
#> [1] "/private/var/folders/9r/xzfp9lgn603578400ms53lr00000gn/T/Rtmpl7dmnd/temp_libpath1e8b23a8b4ad/lifelihood/configs/config2.yaml"